#nucosCR -- a convenient cryptography tools provider in python, works as a working toolbox for pycrypto
This module is in alpha stage, any usage is on own responsibility.

#Recommended test runner
nose2 --plugin nose2.plugins.junitxml --junit-xml
